@@ -1,4 +1,3 @@
-#![feature(try_trait)]
 #![feature(generators, generator_trait)]
 mod app;
 mod cache;
@@ -25,6 +24,9 @@ use tui::Terminal;
 
 use crate::util::event::{Event, Events};
 
+#[macro_use]
+extern crate combine;
+
 #[derive(Clap)]
 #[clap(
   version = env!("CARGO_PKG_VERSION"),
